Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1152)

Unified Diff: src/runtime/runtime-function.cc

Issue 1442643002: [turbofan] Rename "original constructor" to "new target". (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Rebased. Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/runtime/runtime.h ('k') | test/cctest/interpreter/test-bytecode-generator.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/runtime/runtime-function.cc
diff --git a/src/runtime/runtime-function.cc b/src/runtime/runtime-function.cc
index 7bddb09f0a1f7880b74cb32af81fc7507719193e..b1dfd4af782c4290fd6c6728f1a7d3ad2328773e 100644
--- a/src/runtime/runtime-function.cc
+++ b/src/runtime/runtime-function.cc
@@ -565,13 +565,13 @@ RUNTIME_FUNCTION(Runtime_Apply) {
}
-RUNTIME_FUNCTION(Runtime_GetOriginalConstructor) {
+RUNTIME_FUNCTION(Runtime_GetNewTarget) {
SealHandleScope shs(isolate);
DCHECK(args.length() == 0);
JavaScriptFrameIterator it(isolate);
JavaScriptFrame* frame = it.frame();
// TODO(4544): Currently we never inline any [[Construct]] calls where the
// actual constructor differs from the original constructor. Fix this soon!
if (frame->HasInlinedFrames()) {
HandleScope scope(isolate);
List<FrameSummary> frames(FLAG_max_inlining_levels + 1);
@@ -580,7 +580,7 @@ RUNTIME_FUNCTION(Runtime_GetOriginalConstructor) {
return summary.is_constructor() ? Object::cast(*summary.function())
: isolate->heap()->undefined_value();
}
- return frame->IsConstructor() ? frame->GetOriginalConstructor()
+ return frame->IsConstructor() ? frame->GetNewTarget()
: isolate->heap()->undefined_value();
}
« no previous file with comments | « src/runtime/runtime.h ('k') | test/cctest/interpreter/test-bytecode-generator.cc » ('j') | no next file with comments »
@@ -565,13 +565,13 @@ RUNTIME_FUNCTION(Runtime_Apply) {
JavaScriptFrame* frame = it.frame();
// TODO(4544): Currently we never inline any [[Construct]] calls where the
- // actual constructor differs from the original constructor. Fix this soon!
+ // actual target differs from the new target. Fix this soon!
if (frame->HasInlinedFrames()) {
HandleScope scope(isolate);

Powered by Google App Engine
This is Rietveld 408576698